@@ -26,6 +26,7 @@ class Gui(object):
 
     def __init__(self):
         _moduleLogger.info("Starting GUI")
+        self._clipboard = gtk.clipboard_get()
         self._callMonitor = CallMonitor.CallMonitor()
         self.__settingsWindow = None
         self.__settingsManager = None
@@ -526,7 +527,7 @@ class Gui(object):
 
     def set_button_text(self, title, text):
         if hildonize.IS_FREMANTLE_SUPPORTED:
-            self.button.set_text("Resume", "Resume playing the audiobook")
+            self.button.set_text(title, text)
         else:
             self.button.set_label("%s - %s" % (title, text))
 
